from airflow import DAG
from datetime import datetime
from airflow.operators.bash import BashOperator
from airflow.providers.cncf.kubernetes.operators.kubernetes_pod import KubernetesPodOperator
from airflow.configuration import conf

namespace = conf.get("kubernetes", "NAMESPACE")

# set the name that will be printed
name = "luoyulong"

# instantiate the DAG
with DAG(
        start_date=datetime(2022, 6, 1),
        catchup=False,
        schedule_interval=None,
        dag_id="dag_data_transfer"
) as dag:
    op_transfer_data = KubernetesPodOperator(
        task_id="task_000",
        image="SXKJ:32775/jupyter:0.96",
        in_cluster=True,
        namespace=namespace,
        name="transfer_data",
        random_name_suffix=True,
        labels={'app': 'backend', 'env': 'dev'},
        reattach_on_restart=True,
        is_delete_operator_pod=False,
        get_logs=True,
        log_events_on_failure=True,
        cmds=['/bin/bash', '-c',
              'kinit -kt /workspace/conf/user.keytab ailab & cd /workspace && echo "$SCRIPT" > run.py && ${SPARK_HOME}/bin/spark-submit --name spark_data_transfer --master yarn --deploy-mode cluster --driver-memory 1g --driver-cores  1 --executor-memory 1g --executor-cores 1 --num-executors 1 --archives /workspace/py37.zip#python3env --conf spark.default.parallelism=1 --conf spark.executor.memoryOverhead=1g --conf spark.driver.memoryOverhead=1g --conf spark.yarn.maxAppAttempts=1 --conf spark.yarn.submit.waitAppCompletion=true --conf spark.pyspark.driver.python=python3env/py37/bin/python --conf spark.yarn.appMasterEnv.PYSPARK_PYTHON=python3env/py37/bin/python --conf spark.pyspark.python=python3env/py37/bin/python run.py'],
        env_vars={{env}}
    )

